set YES_ 257
set NO_ 258
set ON_ 259
set OFF_ 260
set TRUE_ 261
set FALSE_ 262
set CLEAR_ 263
set CLOSE_ 264
set COORD_ 265
set CROSSHAIR_ 266
set CURRENT_ 267
set FRAME_ 268
set NAME_ 269
set NEW_ 270
set OPEN_ 271
set UPDATE_ 272
set SAVE_ 273
set SIZE_ 274
set SURVEY_ 275
set DEGREES_ 276
set ARCMIN_ 277
set ARCSEC_ 278
set SEXAGESIMAL_ 279
set SEXSTR_ 280
set INT_ 281
set REAL_ 282
set STRING_ 283
set DSS1_ 284
set DSS2_RED_ 285
set DSS2_BLUE_ 286
set DSS2_INFRARED_ 287
